/*
 * RunBatchActionDelegate.java
 * 
 * Copyright 2003-2004 Stefan Reichert.
 * All Rights Reserved.
 * 
 * This software is the proprietary information of Stefan Reichert.
 * Use is subject to license terms.
 * 
 */
package net.sf.wickedshell.action.batch;

import java.io.File;

import net.sf.wickedshell.ShellID;
import net.sf.wickedshell.domain.batch.BatchFileDescriptor;
import net.sf.wickedshell.facade.descriptor.IShellDescriptor;
import net.sf.wickedshell.preferences.PreferenceHelper;
import net.sf.wickedshell.ui.shell.ShellView;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

/**
 * @author Stefan Reichert
 * @since 03.06.2005
 */
public class RunBatchFileAction implements IViewActionDelegate {

	/** The <code>IViewPart</code>. */
	private IViewPart view;
	/** The selected <code>BatchFileDescriptor</code> to be run in the shell. */
	private BatchFileDescriptor batchFileDescriptor;

	/**
	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
	 */
	public void init(IViewPart view) {
		this.view = view;
	}

	/**
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	public void run(IAction action) {
		if (batchFileDescriptor != null) {
			File selectedFile = new File(batchFileDescriptor.getFilename());
			ShellView shellView = (ShellView) view.getSite().getPage().findView(ShellID.SHELL_VIEW_ID);
			if (shellView != null) {
				view.getSite().getPage().activate(shellView);
				StringBuffer commandBuffer = new StringBuffer();
				commandBuffer.append(selectedFile.getAbsolutePath());
				if (batchFileDescriptor.getParameters() != null) {
					commandBuffer.append(" ");
					commandBuffer.append(batchFileDescriptor.getParameters());
				}
				shellView.getShellViewer().getShellFacade().executeCommand(commandBuffer.toString());
			}
			else {
				// MessageDialog.openInformation(view.getSite().getShell(), "Wicked Shell",
				//						"The Shell is not open. Please open it first to run the selected Batch File.");
			}
		}
	}

	/**
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
		if (selection.isEmpty()) {
			batchFileDescriptor = null;
		}
		else {
			IStructuredSelection structuredSelection = (IStructuredSelection) selection;
			Object selectedElement = structuredSelection.getFirstElement();
			if (selectedElement instanceof BatchFileDescriptor) {
				batchFileDescriptor = (BatchFileDescriptor) selectedElement;
				IShellDescriptor descriptor = PreferenceHelper.getActiveShellDescriptor();
				action.setEnabled(descriptor.isAllowedForBatchList(new File(batchFileDescriptor
						.getFilename())));
			}
		}
	}

}
